pyparsing: A Python parsing module
==================================

Description
-----------

A Python Parsing Module

License
-------

MIT License


Upstream Contact
----------------

https://pypi.org/project/pyparsing/

